var thirstyFunctions;

jQuery( document ).ready( function($) {

    thirstyFunctions = {

        /**
         * Record link clicks AJAX event trigger.
         *
         * @since 3.0.0
         */
        recordLinkStat : function() {

            $( 'body' ).delegate( 'a' , 'click' , function(e) {

                var $link   = $(this),
                    href    = $link.attr( 'href' ),
                    linkID  = $(this).data( 'linkid' ),
                    href    = thirstyFunctions.isThirstyLink( href );

                if ( href || linkID ) {

                    $.post( thirsty_global_vars.ajax_url , {
                        action  : 'ta_click_data_redirect',
                        href    : href,
                        page    : window.location.href,
                        link_id : linkID
                    } );
                }

            });
        },

        /**
         * Function to check if the loaded link is a ThirstyAffiliates link or not.
         *
         * @since 3.0.0
         */
        isThirstyLink : function( href ) {

            if ( ! href )
                return;

            var link_uri    = href.replace( thirsty_global_vars.home_url , '' ),
                link_prefix = link_uri.substr( 0 , link_uri.indexOf( '/' ) ),
                new_href    = href.replace( '/' + link_prefix + '/' , '/' + thirsty_global_vars.link_prefix + '/' );

            return ( link_prefix && $.inArray( link_prefix , link_prefixes ) > -1 ) ? new_href : false;
        },

        /**
         * Function to check if the loaded link is a ThirstyAffiliates link or not.
         *
         * @since 3.0.0
         */
        linkFixer : function() {

            if ( thirsty_global_vars.link_fixer_enabled !== 'yes' )
                return;

            var $allLinks = $( 'body a' ),
                hrefs     = [],
                href, linkClass, isShortcode, isImage, content;

            // fetch all links that are thirstylinks
            for ( key = 0; key < $allLinks.length; key++ ) {

                href        = $( $allLinks[ key ] ).attr( 'href' );
                linkClass   = $( $allLinks[ key ] ).attr( 'class' );
                isShortcode = $( $allLinks[ key ] ).data( 'shortcode' );
                isImage     = $( $allLinks[ key ] ).has( 'img' ).length;
                content     = $( $allLinks[ key ] ).text();
                href        = thirstyFunctions.isThirstyLink( href );

                if ( href && ! isShortcode )
                    hrefs.push({ key : key , class : linkClass , href : href , content : content , is_image : isImage });

                $( $allLinks[ key ] ).removeAttr( 'data-shortcode' );
            }

            // skip if there are no affiliate links
            if ( hrefs.length < 1 )
                return;

            $.post( thirsty_global_vars.ajax_url , {
                action  : 'ta_link_fixer',
                hrefs   : hrefs,
                post_id : thirsty_global_vars.post_id
            }, function( response ) {

                if ( response.status == 'success' ) {

                    for ( x in response.data ) {

                        key  = response.data[ x ][ 'key' ];
                        html = response.data[ x ][ 'html' ];

                        if ( parseInt( response.data[ x ][ 'is_image' ] ) )
                            html = html.replace( '{image_placeholder}' , $( $allLinks[ key ] ).html() );

                        $( $allLinks[ key ] ).replaceWith( html );
                    }
                }
            }, 'json' );
        }
    }

    var link_prefixes = $.map( thirsty_global_vars.link_prefixes , function(value , index) {
        return [value];
    });

    // Initiate record link click stat function
    thirstyFunctions.recordLinkStat();

    // Initialize uncloak links function
    thirstyFunctions.linkFixer();
});
